==> MMDX-v1.10a-src.zip: MMDX-v1.10a-src/MikuMikuDanceXNADemo2/Game1.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
using MikuMikuDance.XNA;
using MikuMikuDance.XNA.Model;
using MikuMikuDance.XNA.Motion;

namespace MikuMikuDanceXNADemo2
{
    /// <summary>
    /// MikuMikuDance for XNÃf2
    /// ̃fł
    /// -Q[ł̃[ṼxCN
    /// -RecpCvCł̃[ṼxCN
    /// Ă܂
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        //MikuMikuDance for XNA
        MikuMikuDanceXNA mmd;
        //MMDff[^
        MMDModel model1,model2;
        //MMD[Vf[^
        MMDMotion motion1;
        //xCNς݃[Vf[^
        MMDBakedMotion motion2;

        public Game1()
        {
            //foCXMMDX̕Kv𖞂Ă邩`FbN
            graphics = new GraphicsDeviceManager(this);
            MikuMikuDanceXNA.CheckDevice(graphics); 
            Content.RootDirectory = "Content";
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        /// <summary>
        /// LoadContent֐
        /// e탍[h͂Ń[hsĂƗǂ
        /// </summary>
        protected override void LoadContent()
        {
            //MikuMikuDanceXNA쐬
            mmd = new MikuMikuDanceXNA(this);
            //vWFNgContentɒǉĂMiku.pmd, Miku-metal.pmdf[h
            //[hMikuMikuDanceXNA.LoadModel֐ōs
            //(ff[^͂ɂ܂肨؂肵܂B̃ft@CMITCZXKOł)
            model1 = mmd.LoadModel("Miku", this, Matrix.CreateTranslation(-10, 0, -10));
            model2 = mmd.LoadModel("Miku-metal", this, Matrix.CreateTranslation(10, 0, -10));
            //ContentɒǉĂTrueMyHeart.vmd[V[h
            //[hMikuMikuDanceXNA.LoadMotion֐ōs
            motion1 = mmd.LoadMotion("TrueMyHeart");
            
            //model2GPU_Aj[V[hIɂ
            //GPU_Aj[V[hƂ͕\Aj[VvZCPUł͂ȂGPUŏ郂[h
            //GPUtɎg(XBox360fXNgbvPC)Ȃ獂BAGPUアm[gł͋tɒx
            //Windwos̓ftHgfalse,XBox̓ftHgtrueBRpCIvVGPUAnimeŐ؂ւ\
            model2.GPUAnimation = true;

            //model1̓[VZbgAQ[̃xCNs
            //model2̓RecpCvC̃xCN[VZbg
            //xCNƂ́AMMD̃{[ԌvZIK{[̌vZƂd
            //炩ߌvZĂƂCPUׂ̕炵sx啝ɏ㏸鏈ł
            //(XBox360CPU͔Ɏア߁Ȁ͕s)
            //ӓ_
            //1.xCNς݃[V͑̎ނ̃fł͕̓ۏ؂Ȃ({[Ȃ瓮ȁH)
            //2.xCN̓(Ɋ܂܂{[Ⓒ_ɂ邪A2̃[V1.2Mbyte`)
            //3.Q[̃xCNꍇAxCN͓RȂd(}`XbhčĂ邪XBox360ゾƍĐԂ1/6͂BCPUǂ΂ɏI邪)
            //4.RecpCvCŃrhꍇAt@CTCYRȂ傫Ȃ(XBoxł̓ǂݍ݂͑ł)
            
            //model1̃f̃vC[Ăяo
            //[V0ԃgbNɃZbg
            model1.Player.SetMotion(0, motion1, true);
            //0ԃ[VxCN(ō
            model1.Player.BakeMotion(0);
            
            //RecpCvCł̃xCN@XMLgp
            //쐬@
            //-܂TrueMyHeartB.xmlɏĂ悤ɋLq(̕ӂ͂ЂɂXNA񂪏ڂ̂łQ)
            //-ɃRecvZbTuMikuMikuDance[VxCN:MikuMikuDancd for XNAvɂ
            //LoadBakedMotion.xmlǂݍ
            
            //xCNς݃[V̓ǂݍ
            motion2 = mmd.LoadBakedMotion("TrueMyHeartB");
            //[V0ԃgbNɃZbg
            model2.Player.SetMotion(0, motion2, true);
        }

        /// <summary>
        /// UnloadContent֐
        /// A[hKvȕ͂ŃA[hs
        /// </summary>
        protected override void UnloadContent()
        {
        }

        /// <summary>
        /// Abvf[g֐
        /// t[`ȊÕR[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Update(GameTime gameTime)
        {
            //XBoxRg[[Back{^I
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();
            //L[{[hEscL[I
            if (Keyboard.GetState().IsKeyDown(Keys.Escape))
                this.Exit();
            //G^[L[orA{^Ƃ
            if (Keyboard.GetState().IsKeyDown(Keys.Enter) || GamePad.GetState(PlayerIndex.One).Buttons.A == ButtonState.Pressed)
            {
                //ݍĐłȂ
                if (!model1.Player.IsPlay(0))
                {
                    //0ԃgbNɃZbgĂ郂[VZbg
                    model1.Player.Reset(0);
                    model2.Player.Reset(0);
                    //0ԃgbNɃZbgĂ郂[VĐ
                    model1.Player.Start(0, false);
                    model2.Player.Start(0, false);
                }
            }

            //f̍ĐDrawableGameComponentpĂ邽
            //XNAɂ莩ŏs

            //XNAUpdates
            base.Update(gameTime);
        }

        /// <summary>
        /// Draw֐
        /// t[`R[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Draw(GameTime gameTime)
        {
            //ʂCornflowerBlueFŏ
            GraphicsDevice.Clear(Color.CornflowerBlue);

            //fDrawableGameComponentpĂ邽
            //XNAɂ莩ŕ`悳

            //XNADraws
            base.Draw(gameTime);
        }
    }
}

==> MMDX-v1.20a-src.zip: MMDX-v1.20a-src/MikuMikuDanceXNADemo2/Game1.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
using MikuMikuDance.XNA;
using MikuMikuDance.XNA.Model;
using MikuMikuDance.XNA.Motion;

namespace MikuMikuDanceXNADemo2
{
    /// <summary>
    /// MikuMikuDance for XNÃf2
    /// ̃fł
    /// -Q[ł̃[ṼxCN
    /// -RecpCvCł̃[ṼxCN
    /// Ă܂
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        //MikuMikuDance for XNA
        MikuMikuDanceXNA mmd;
        //MMDff[^
        MMDModel model1,model2;
        //MMD[Vf[^
        MMDMotion motion1;
        //xCNς݃[Vf[^
        MMDBakedMotion motion2;

        public Game1()
        {
            //foCXMMDX̕Kv𖞂Ă邩`FbN
            graphics = new GraphicsDeviceManager(this);
            MikuMikuDanceXNA.CheckDevice(graphics, true); 
            Content.RootDirectory = "Content";
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        /// <summary>
        /// LoadContent֐
        /// e탍[h͂Ń[hsĂƗǂ
        /// </summary>
        protected override void LoadContent()
        {
            //MikuMikuDanceXNA쐬
            mmd = new MikuMikuDanceXNA(this);
            //vWFNgContentɒǉĂMiku.pmd, Miku-metal.pmdf[h
            //[hMikuMikuDanceXNA.LoadModel֐ōs
            //(ff[^͂ɂ܂肨؂肵܂B̃ft@CMITCZXKOł)
            model1 = mmd.LoadModel("Miku", this, Matrix.CreateTranslation(-10, 0, -10));
            model2 = mmd.LoadModel("Miku-metal", this, Matrix.CreateTranslation(10, 0, -10));
            //ContentɒǉĂTrueMyHeart.vmd[V[h
            //[hMikuMikuDanceXNA.LoadMotion֐ōs
            motion1 = mmd.LoadMotion("TrueMyHeart");
            
            //model2GPU_Aj[V[hIɂ
            //GPU_Aj[V[hƂ͕\Aj[VvZCPUł͂ȂGPUŏ郂[h
            //GPUtɎg(XBox360fXNgbvPC)Ȃ獂BAGPUアm[gł͋tɒx
            //Windwos̓ftHgfalse,XBox̓ftHgtrueBRpCIvVGPUAnimeŐ؂ւ\
            model2.GPUAnimation = true;

            //model1̓[VZbgAQ[̃xCNs
            //model2̓RecpCvC̃xCN[VZbg
            //xCNƂ́AMMD̃{[ԌvZIK{[̌vZƂd
            //炩ߌvZĂƂCPUׂ̕炵sx啝ɏ㏸鏈ł
            //(XBox360CPU͔Ɏア߁Ȁ͕s)
            //ӓ_
            //1.xCNς݃[V͑̎ނ̃fł͕̓ۏ؂Ȃ({[Ȃ瓮ȁH)
            //2.xCN̓(Ɋ܂܂{[Ⓒ_ɂ邪A2̃[V1.2Mbyte`)
            //3.Q[̃xCNꍇAxCN͓RȂd(}`XbhčĂ邪XBox360ゾƍĐԂ1/6͂BCPUǂ΂ɏI邪)
            //4.RecpCvCŃrhꍇAt@CTCYRȂ傫Ȃ(XBoxł̓ǂݍ݂͑ł)
            
            //model1̃f̃vC[Ăяo
            //[V0ԃgbNɃZbg
            model1.Player.SetMotion(0, motion1, true);
            //0ԃ[VxCN(ō
            model1.Player.BakeMotion(0);
            
            //RecpCvCł̃xCN@XMLgp
            //쐬@
            //-܂TrueMyHeartB.xmlɏĂ悤ɋLq(̕ӂ͂ЂɂXNA񂪏ڂ̂łQ)
            //-ɃRecvZbTuMikuMikuDance[VxCN:MikuMikuDancd for XNAvɂ
            //LoadBakedMotion.xmlǂݍ
            
            //xCNς݃[V̓ǂݍ
            motion2 = mmd.LoadBakedMotion("TrueMyHeartB");
            //[V0ԃgbNɃZbg
            model2.Player.SetMotion(0, motion2, true);
        }

        /// <summary>
        /// UnloadContent֐
        /// A[hKvȕ͂ŃA[hs
        /// </summary>
        protected override void UnloadContent()
        {
        }

        /// <summary>
        /// Abvf[g֐
        /// t[`ȊÕR[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Update(GameTime gameTime)
        {
            //XBoxRg[[Back{^I
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();
            //L[{[hEscL[I
            if (Keyboard.GetState().IsKeyDown(Keys.Escape))
                this.Exit();
            //G^[L[orA{^Ƃ
            if (Keyboard.GetState().IsKeyDown(Keys.Enter) || GamePad.GetState(PlayerIndex.One).Buttons.A == ButtonState.Pressed)
            {
                //ݍĐłȂ
                if (!model1.Player.IsPlay(0))
                {
                    //0ԃgbNɃZbgĂ郂[VZbg
                    model1.Player.Reset(0);
                    model2.Player.Reset(0);
                    //0ԃgbNɃZbgĂ郂[VĐ
                    model1.Player.Start(0, false);
                    model2.Player.Start(0, false);
                }
            }

            //f̍ĐDrawableGameComponentpĂ邽
            //XNAɂ莩ŏs

            //XNAUpdates
            base.Update(gameTime);
        }

        /// <summary>
        /// Draw֐
        /// t[`R[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Draw(GameTime gameTime)
        {
            //ʂCornflowerBlueFŏ
            GraphicsDevice.Clear(Color.CornflowerBlue);

            //fDrawableGameComponentpĂ邽
            //XNAɂ莩ŕ`悳

            //XNADraws
            base.Draw(gameTime);
        }
    }
}
